==================================
Input and output (:mod:`scipy.io`)
==================================

.. seealso:: :ref:`numpy-reference.routines.io` (in Numpy)

.. module:: scipy.io

MATLAB® files
=============

.. autosummary::
   :toctree: generated/

   loadmat
   savemat

Matrix Market files
===================

.. autosummary::
   :toctree: generated/

   mminfo
   mmread
   mmwrite

Other
=====

.. autosummary::
   :toctree: generated/

   save_as_module

Wav sound files (:mod:`scipy.io.wavfile`)
=========================================

.. module:: scipy.io.wavfile

.. autosummary::
   :toctree: generated/

   read
   write

Arff files (:mod:`scipy.io.arff`)
=================================

.. automodule:: scipy.io.arff

.. autosummary::
   :toctree: generated/

   loadarff

Netcdf (:mod:`scipy.io.netcdf`)
===============================

.. module:: scipy.io.netcdf

.. autosummary::
   :toctree: generated/

   netcdf_file
   netcdf_variable
